@@ -518,6 +518,75 @@ def status():
         click.echo("Run 'watchcode install-hooks' to install missing hooks.")
 
 
+@main.command()
+@click.option("--clear", is_flag=True, help="Unregister device and clear local configuration")
+@click.option("--verify", is_flag=True, help="Verify device registration on relay server")
+@click.option("--yes", "-y", is_flag=True, help="Skip confirmation prompt for --clear")
+def devices(clear: bool, verify: bool, yes: bool):
+    """Manage device registration.
+
+    Shows current device configuration by default.
+    Use --clear to unregister and remove local config.
+    Use --verify to check if device is registered on relay server.
+    """
+    config = Config()
+
+    if not config.is_configured():
+        click.echo("WatchCode not configured. Run 'watchcode setup' first.", err=True)
+        sys.exit(1)
+
+    token = config.get_auth_token()
+
+    if verify:
+        # Check if token is valid on relay
+        click.echo(f"Verifying device {config.format_token_display(token)}...")
+        client = RelayClient(config)
+        is_valid = client.verify_device()
+        if is_valid:
+            click.echo(f"Device is registered and active on relay server.")
+        else:
+            click.echo(f"Device is NOT registered on relay server.", err=True)
+            click.echo("Run 'watchcode setup' to re-register.")
+            sys.exit(1)
+        return
+
+    if clear:
+        if not yes:
+            click.echo(f"This will unregister device {config.format_token_display(token)} and clear local config.")
+            if not click.confirm("Continue?"):
+                click.echo("Cancelled.")
+                return
+
+        # Unregister from relay
+        click.echo("Unregistering from relay server...", nl=False)
+        client = RelayClient(config)
+        try:
+            client.unregister_device()
+            click.echo(" Done")
+        except Exception as e:
+            click.echo(f" Warning: {e}", err=True)
+            click.echo("  (Continuing with local cleanup)")
+
+        # Clear local config
+        click.echo("Clearing local configuration...", nl=False)
+        config.delete_auth_token()
+        click.echo(" Done")
+
+        click.echo()
+        click.echo("Device cleared. Run 'watchcode setup' to configure a new device.")
+        return
+
+    # Default: show device info
+    click.echo("Device Configuration")
+    click.echo("=" * 50)
+    click.echo(f"Setup code: {config.format_token_display(token)}")
+    click.echo(f"Storage: {config.get_storage_location()}")
+    click.echo(f"Relay: {config.get_relay_url()}")
+    click.echo()
+    click.echo("Use --verify to check relay registration status.")
+    click.echo("Use --clear to unregister and remove configuration.")
+
+
 @main.command()
 def flush():
     """Send queued offline notifications."""
